@@ -197,23 +197,25 @@ static int sdla_te3_polling(sdla_fe_t *fe)
 				fe->name,prev_status,fe->fe_status,fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout,
 				(SYSTEM_TICKS-fe->fe_param.te3.disc_timeout)/HZ);
 
-	if (1 || fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout) {
-		if (prev_status == FE_CONNECTED) {
-			if (fe->fe_status == FE_DISCONNECTED) {
-				DEBUG_TEST("%s: FE_DISCONNECTED checking timeout %lu\n",
-					fe->name,	(SYSTEM_TICKS-fe->fe_param.te3.disc_timeout));
-	
-				if (1 || (SYSTEM_TICKS-fe->fe_param.te3.disc_timeout) < (fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout*HZ)) {
-					DEBUG_EVENT("%s: FE Disconnect - resetting FE %i\n",
-								card->devname,fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout);
-					sdla_te3_config(fe);
+	if (fe_cfg->media == WAN_MEDIA_DS3){
+		if (1 || fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout) {
+			if (prev_status == FE_CONNECTED) {
+				if (fe->fe_status == FE_DISCONNECTED) {
+					DEBUG_TEST("%s: FE_DISCONNECTED checking timeout %lu\n",
+						fe->name,	(SYSTEM_TICKS-fe->fe_param.te3.disc_timeout));
+		
+					if (1 || (SYSTEM_TICKS-fe->fe_param.te3.disc_timeout) < (fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout*HZ)) {
+						DEBUG_EVENT("%s: FE Disconnect - resetting FE %i\n",
+									card->devname,fe->fe_cfg.cfg.te3_cfg.disc_cfg_timeout);
+						sdla_te3_config(fe);
+					}
+				}
+			} else {
+				if (fe->fe_status == FE_CONNECTED) {
+					fe->fe_param.te3.disc_timeout=SYSTEM_TICKS;
+					DEBUG_TEST("%s: FE_CONNECTED resetting timeout %lu\n",
+						fe->name,	(SYSTEM_TICKS-fe->fe_param.te3.disc_timeout)/HZ);
 				}
-			}
-		} else {
-			if (fe->fe_status == FE_CONNECTED) {
-				fe->fe_param.te3.disc_timeout=SYSTEM_TICKS;
-				DEBUG_TEST("%s: FE_CONNECTED resetting timeout %lu\n",
-					fe->name,	(SYSTEM_TICKS-fe->fe_param.te3.disc_timeout)/HZ);
 			}
 		}
 	}
@@ -1405,7 +1407,10 @@ static int sdla_te3_config(void *p_fe)
 
 	DEBUG_EVENT("%s: %s disconnected!\n",
 					fe->name, FE_MEDIA_DECODE(fe));
-	//sdla_te3_read_alarms(fe, 1);
+
+	if (fe_cfg->media == WAN_MEDIA_E3){
+		sdla_te3_read_alarms(fe, 1);
+	}
 	//sdla_te3_set_intr(fe);
 	return 0;
 }
